---
title: <span class="badge builder"></span> OptionsWithTimezones
---
# <span class="badge builder"></span> OptionsWithTimezones

## Constructor

```python
OptionsWithTimezones()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> common.OptionsWithTimezones
```

### <span class="badge object-method"></span> timezone

```python
def timezone(timezone: list[common.TimeZone]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [OptionsWithTimezones](./object-OptionsWithTimezones.md)
